@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 3.1 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.2 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2003, Mark Calabretta
 *
 *   This library is free software; you can redistribute it and/or modify it
@@ -27,7 +27,7 @@
 *
 *=============================================================================
 *
-*   WCSLIB 3.1 - C routines that implement the FITS World Coordinate System
+*   WCSLIB 3.2 - C routines that implement the FITS World Coordinate System
 *   (WCS) convention.  Refer to
 *
 *      "Representations of world coordinates in FITS",
@@ -64,18 +64,25 @@
 *                        arrays.  Otherwise, it is assumed that pointers to
 *                        these arrays have been set by the caller except if
 *                        they are null pointers in which case memory will be
-*                        allocated for them regardless.
+*                        allocated for them regardless.  (In other words,
+*                        setting alloc true saves having to initalize these
+*                        pointers to zero.)
 *      naxis    int      The number of world coordinate axes, used to
 *                        determine array sizes.
 *
-*   Returned:
+*   Given and returned:
 *      lin      struct linprm*
 *                        Linear transformation parameters (see below).
+*                        Note that, in order to initialize memory management
+*                        lin->flag should be set to -1 when lin is initialized
+*                        for the first time (memory leaks may result if it had
+*                        already been initialized).
 *
 *   Function return value:
 *               int      Error status
 *                           0: Success.
-*                           1: Memory allocation error.
+*                           1: Null linprm pointer passed.
+*                           2: Memory allocation error.
 *
 *
 *   lincpy() does a deep copy of one linprm struct to another, using linini()
@@ -92,27 +99,31 @@
 *      linsrc   const struct linprm*
 *                        Struct to copy from.
 *
-*   Returned:
+*   Given and returned:
 *      lindst   struct linprm*
-*                        Struct to copy to.
+*                        Struct to copy to.  lindst->flag should be set to -1
+*                        if lindst was not previously initialized (memory
+*                        leaks may result if it was previously initialized).
 *
 *   Function return value:
 *               int      Error status
 *                           0: Success.
-*                           1: Memory allocation error.
+*                           1: Null linprm pointer passed.
+*                           2: Memory allocation error.
 *
 *
 *   linfree() frees memory allocated for the linprm arrays by linini() and/or
 *   linset().  linini() keeps a record of the memory it allocates and
 *   linfree() will only attempt to free this.
 *
-*   Returned:
+*   Given:
 *      lin      struct linprm*
 *                        Linear transformation parameters (see below).
 *
 *   Function return value:
 *               int      Error status
 *                           0: Success.
+*                           1: Null linprm pointer passed.
 *
 *
 *   Print routine for the linprm struct; linprt()
@@ -126,6 +137,7 @@
 *   Function return value:
 *               int      Error status
 *                           0: Success.
+*                           1: Null linprm pointer passed.
 *
 *
 *   Initialization routine; linset()
@@ -145,8 +157,9 @@
 *   Function return value:
 *               int      Error status
 *                           0: Success.
-*                           1: Memory allocation error.
-*                           2: PC matrix is singular.
+*                           1: Null linprm pointer passed.
+*                           2: Memory allocation error.
+*                           3: PC matrix is singular.
 *
 *
 *   Pixel-to-world transformation; linp2x()
@@ -172,8 +185,9 @@
 *   Function return value:
 *               int      Error status
 *                           0: Success.
-*                           1: Memory allocation error.
-*                           2: PC matrix is singular.
+*                           1: Null linprm pointer passed.
+*                           2: Memory allocation error.
+*                           3: PC matrix is singular.
 *
 *
 *   World-to-pixel transformation; linx2p()
@@ -199,8 +213,9 @@
 *   Function return value:
 *               int      Error status
 *                           0: Success.
-*                           1: Memory allocation error.
-*                           2: PC matrix is singular.
+*                           1: Null linprm pointer passed.
+*                           2: Memory allocation error.
+*                           3: PC matrix is singular.
 *
 *
 *   Linear transformation parameters
@@ -209,8 +224,13 @@
 *
 *      int flag
 *         This flag must be set to zero whenever any of the following members
-*         are set or modified.  This signals the initialization routine,
-*         linset(), to recompute intermediaries.
+*         of the linprm struct are set or modified.  This signals the
+*         initialization routine, linset(), to recompute intermediaries.
+*
+*         flag should be set to -1 when linini() is called for the first time
+*         for a linprm struct in order to initialize memory management.  It
+*         must ONLY be used on the first initialization otherwise memory leaks
+*         may result.
 *
 *      int naxis
 *         Number of pixel and world coordinate elements.
@@ -311,13 +331,12 @@
 *
 *   Error codes
 *   -----------
-*   Error messages to match the error codes for linini(), lincpy(), linset(),
-*   linp2x(), and linx2p() are encoded in the linini_errmsg, lincpy_errmsg,
-*   linset_errmsg, linp2x_errmsg, and linx2p_errmsg character arrays.
+*   Error messages to match the error codes returned from each function are
+*   encoded in the lin_errmsg character array.
 *
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
-*   $Id: lin.h,v 3.1 2003/04/28 03:50:41 mcalabre Exp $
+*   $Id: lin.h,v 3.2 2003/09/09 04:04:04 mcalabre Exp $
 *===========================================================================*/
 
 #ifndef WCSLIB_LIN
@@ -334,11 +353,14 @@ extern "C" {
 #endif
 
 
-extern const char *linini_errmsg[];
-extern const char *lincpy_errmsg[];
-extern const char *linset_errmsg[];
-extern const char *linp2x_errmsg[];
-extern const char *linx2p_errmsg[];
+extern const char *lin_errmsg[];
+#define linini_errmsg lin_errmsg
+#define lincpy_errmsg lin_errmsg
+#define linfree_errmsg lin_errmsg
+#define linprt_errmsg lin_errmsg
+#define linset_errmsg lin_errmsg
+#define linp2x_errmsg lin_errmsg
+#define linx2p_errmsg lin_errmsg
 
 
 struct linprm {
@@ -387,8 +409,8 @@ struct linprm {
 
 
 /* Define macros for scalar invokation for compatibility with WCSLIB 2.x. */
-extern const char *linfwd_errmsg[];
-extern const char *linrev_errmsg[];
+#define linrev_errmsg lin_errmsg;
+#define linfwd_errmsg lin_errmsg;
 #define linrev(pixcrd, lin, imgcrd) linp2x(lin, 1, 1, pixcrd, imgcrd)
 #define linfwd(imgcrd, lin, pixcrd) linx2p(lin, 1, 1, imgcrd, pixcrd)
 
