@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 3.1 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.2 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2003, Mark Calabretta
 *
 *   This library is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 *                      AUSTRALIA
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
-*   $Id: spc.c,v 3.1 2003/04/28 03:50:41 mcalabre Exp $
+*   $Id: spc.c,v 3.2 2003/09/09 04:04:04 mcalabre Exp $
 *===========================================================================*/
 
 #include <math.h>
@@ -70,20 +70,13 @@ const char spc_codes[15][4] =
 #define BETA 31;		/* Velocity-like.                     */
 
 
-/* Map error number to error message for each function. */
-const char *spcset_errmsg[] = {
-   0,
-   "Invalid spectral parameters"};
-
-const char *spcx2s_errmsg[] = {
+/* Map error number to error message. */
+const char *spc_errmsg[] = {
    0,
+   "Null spcprm pointer passed",
    "Invalid spectral parameters",
-   "Invalid value of x"};
-
-const char *spcs2x_errmsg[] = {
-   0,
-   "Invalid spectral parameters",
-   "Invalid spectral coordinate"};
+   "One or more of x coordinates were invalid",
+   "One or more of the spec coordinates were invalid"};
 
 
 #define UNDEFINED 987654321.0e99
@@ -100,6 +93,8 @@ struct spcprm *spc;
 {
    register int k;
 
+   if (spc == 0) return 1;
+
    spc->flag = 0;
 
    strcpy(spc->type, "    ");
@@ -198,11 +193,14 @@ struct spcprm *spc;
 
 {
    char   p, x;
+   int    status;
    double alpha, beta_r, dn_r, epsilon, G, m, lambda_r, n_r, t, theta;
    struct spxprm spx;
 
+   if (spc == 0) return 1;
+
    if (undefined(spc->crval)) {
-      return 1;
+      return 2;
    }
 
    spc->type[4] = '\0';
@@ -227,8 +225,9 @@ struct spcprm *spc;
    }
 
    /* Compute all spectral parameters and their derivatives. */
-   if (specx(spc->type, spc->crval, spc->restfrq, spc->restwav, &spx)) {
-      return 1;
+   if (status = specx(spc->type, spc->crval, spc->restfrq, spc->restwav,
+                      &spx)) {
+      return status;
    }
 
 
@@ -249,12 +248,12 @@ struct spcprm *spc;
 
    if (strcmp(spc->type, "FREQ") == 0) {
       /* Frequency. */
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       if (p == '*') {
          p = 'F';
       } else if (p != 'F') {
-         return 1;
+         return 2;
       }
 
       spc->flag = FREQ;
@@ -264,12 +263,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "AFRQ") == 0) {
       /* Angular frequency. */
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       if (p == '*') {
          p = 'F';
       } else if (p != 'F') {
-         return 1;
+         return 2;
       }
 
       spc->flag = AFRQ;
@@ -279,12 +278,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "ENER") == 0) {
       /* Photon energy. */
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       if (p == '*') {
          p = 'F';
       } else if (p != 'F') {
-         return 1;
+         return 2;
       }
 
       spc->flag = ENER;
@@ -294,12 +293,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "WAVN") == 0) {
       /* Wave number. */
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       if (p == '*') {
          p = 'F';
       } else if (p != 'F') {
-         return 1;
+         return 2;
       }
 
       spc->flag = WAVN;
@@ -309,12 +308,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "VRAD") == 0) {
       /* Radio velocity. */
-      if (!spx.velotype) return 1;
+      if (!spx.velotype) return 2;
 
       if (p == '*') {
          p = 'F';
       } else if (p != 'F') {
-         return 1;
+         return 2;
       }
 
       spc->flag = VRAD;
@@ -325,12 +324,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "WAVE") == 0) {
       /* Vacuum wavelengths. */
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       if (p == '*') {
          p = 'W';
       } else if (p != 'W') {
-         return 1;
+         return 2;
       }
 
       spc->flag = WAVE;
@@ -340,12 +339,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "VOPT") == 0) {
       /* Optical velocity. */
-      if (!spx.velotype) return 1;
+      if (!spx.velotype) return 2;
 
       if (p == '*') {
          p = 'W';
       } else if (p != 'W') {
-         return 1;
+         return 2;
       }
 
       spc->flag = VOPT;
@@ -356,12 +355,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "ZOPT") == 0) {
       /* Redshift. */
-      if (!spx.velotype) return 1;
+      if (!spx.velotype) return 2;
 
       if (p == '*') {
          p = 'W';
       } else if (p != 'W') {
-         return 1;
+         return 2;
       }
 
       spc->flag = ZOPT;
@@ -372,12 +371,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "AWAV") == 0) {
       /* Air wavelengths. */
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       if (p == '*') {
          p = 'A';
       } else if (p != 'A') {
-         return 1;
+         return 2;
       }
 
       spc->flag = AWAV;
@@ -387,12 +386,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "VELO") == 0) {
       /* Relativistic velocity. */
-      if (!spx.velotype) return 1;
+      if (!spx.velotype) return 2;
 
       if (p == '*') {
          p = 'V';
       } else if (p != 'V') {
-         return 1;
+         return 2;
       }
 
       spc->flag = VELO;
@@ -402,12 +401,12 @@ struct spcprm *spc;
 
    } else if (strcmp(spc->type, "BETA") == 0) {
       /* Velocity ratio (v/c). */
-      if (!spx.velotype) return 1;
+      if (!spx.velotype) return 2;
 
       if (p == '*') {
          p = 'V';
       } else if (p != 'V') {
-         return 1;
+         return 2;
       }
 
       spc->flag = BETA;
@@ -417,7 +416,7 @@ struct spcprm *spc;
 
    } else {
       /* Unrecognized coordinate type. */
-      return 1;
+      return 2;
 
    }
 
@@ -427,7 +426,7 @@ struct spcprm *spc;
    x = spc->code[0];
    if (x == 'F') {
       /* Axis is linear in frequency. */
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       if (strcmp(spc->code, "F2W") == 0) {
          spc->w[2] *= spx.dfreqwave;
@@ -447,14 +446,14 @@ struct spcprm *spc;
 
       } else {
          /* Unrecognized spectral algorithm code. */
-         return 1;
+         return 2;
       }
 
       spc->flag += F2S;
       spc->w[1] = spx.freq;
 
    } else if (x == 'W') {
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       /* Axis is linear in vacuum wavelengths. */
       if (strcmp(spc->code, "W2F") == 0) {
@@ -475,14 +474,14 @@ struct spcprm *spc;
 
       } else {
          /* Unrecognized spectral algorithm code. */
-         return 1;
+         return 2;
       }
 
       spc->flag += W2S;
       spc->w[1] = spx.wave;
 
    } else if (x == 'A') {
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       /* Axis is linear in air wavelengths. */
       if (strcmp(spc->code, "A2F") == 0) {
@@ -503,14 +502,14 @@ struct spcprm *spc;
 
       } else {
          /* Unrecognized spectral algorithm code. */
-         return 1;
+         return 2;
       }
 
       spc->flag += A2S;
       spc->w[1] = spx.awav;
 
    } else if (x == 'V') {
-      if (!spx.velotype) return 1;
+      if (!spx.velotype) return 2;
 
       /* Axis is linear in relativistic velocity. */
       if (strcmp(spc->code, "V2F") == 0) {
@@ -533,7 +532,7 @@ struct spcprm *spc;
 
       } else {
          /* Unrecognized spectral algorithm code. */
-         return 1;
+         return 2;
       }
 
       spc->flag += V2S;
@@ -541,7 +540,7 @@ struct spcprm *spc;
 
    } else if (spc->isGrism) {
       /* Axis is linear in "grism parameter"; work in wavelength. */
-      if (!spx.wavetype) return 1;
+      if (!spx.wavetype) return 2;
 
       if (spc->isGrism == 1) {
          /* Grism in vacuum. */
@@ -567,7 +566,7 @@ struct spcprm *spc;
 
          } else {
             /* Shouldn't be possible. */
-            return 1;
+            return 2;
          }
 
          lambda_r = spx.wave;
@@ -597,7 +596,7 @@ struct spcprm *spc;
 
          } else {
             /* Shouldn't be possible. */
-            return 1;
+            return 2;
          }
 
          lambda_r = spx.awav;
@@ -635,7 +634,7 @@ struct spcprm *spc;
 
    } else {
       /* Unrecognized spectral algorithm code. */
-      return 1;
+      return 2;
    }
 
 
@@ -653,16 +652,18 @@ double spec[];
 int stat[];
 
 {
-   int status = 0;
+   int statq2s, status = 0, statx2q;
    double beta;
    register int ix;
    register int *statp;
    register const double *xp;
    register double *specp;
 
+
    /* Initialize. */
+   if (spc == 0) return 1;
    if (spc->flag == 0) {
-      if (spcset(spc)) return 1;
+      if (spcset(spc)) return 2;
    }
 
    /* Convert intermediate world coordinate x to X. */
@@ -686,22 +687,30 @@ int stat[];
    /* Apply the non-linear step of the algorithm chain to convert spectral */
    /* coordinate X to intermediate spectral coordinate Q.                  */
    if (spc->spxx2q != 0) {
-      if (status = spc->spxx2q(spc->w[0], nx, sspec, sspec, spec, spec,
-         stat)) {
-         return status;
+      if (statx2q = spc->spxx2q(spc->w[0], nx, sspec, sspec, spec, spec,
+                                stat)) {
+         if (statx2q == 4) {
+            status = 3;
+         } else {
+            return statx2q;
+         }
       }
    }
 
    /* Apply the linear step of the algorithm chain to convert intermediate */
    /* spectral coordinate Q to the required spectral coordinate S.         */
    if (spc->spxq2s != 0) {
-      if (status = spc->spxq2s(spc->w[0], nx, sspec, sspec, spec, spec,
-         stat)) {
-         return status;
+      if (statq2s = spc->spxq2s(spc->w[0], nx, sspec, sspec, spec, spec,
+                                stat)) {;
+         if (statq2s == 4) {
+            status = 3;
+         } else {
+            return statq2s;
+         }
       }
    }
 
-   return 0;
+   return status;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -715,23 +724,29 @@ double x[];
 int stat[];
 
 {
-   int status = 0;
-   double beta;
+   int statq2x, status = 0, stats2q;
+   double beta, s;
    register int ispec;
    register int *statp;
    register const double *specp;
    register double *xp;
 
+
    /* Initialize. */
+   if (spc == 0) return 1;
    if (spc->flag == 0) {
-      if (spcset(spc)) return 1;
+      if (spcset(spc)) return 2;
    }
 
    /* Apply the linear step of the algorithm chain to convert spectral */
    /* coordinate S to intermediate spectral coordinate Q.              */
    if (spc->spxs2q != 0) {
-      if (status = spc->spxs2q(spc->w[0], nspec, sspec, sx, spec, x, stat)) {
-         return status;
+      if (stats2q = spc->spxs2q(spc->w[0], nspec, sspec, sx, spec, x, stat)) {
+         if (stats2q == 4) {
+            status = 4;
+         } else {
+            return stats2q;
+         }
       }
 
    } else {
@@ -749,17 +764,29 @@ int stat[];
    /* Apply the non-linear step of the algorithm chain to convert  */
    /* intermediate spectral coordinate Q to spectral coordinate X. */
    if (spc->spxq2x != 0) {
-      if (status = spc->spxq2x(spc->w[0], nspec, sx, sx, x, x, stat)) {
-         return status;
+      if (statq2x = spc->spxq2x(spc->w[0], nspec, sx, sx, x, x, stat)) {
+         if (statq2x == 4) {
+            status = 4;
+         } else {
+            return statq2x;
+         }
       }
    }
 
    if (spc->isGrism) {
       /* Convert X (wavelength) to grism parameter. */
       xp = x;
-      for (ispec = 0; ispec < nspec; ispec++, xp += sx) {
-         beta = asind(*xp/spc->w[5] - spc->w[4]);
-         *xp = tand(beta - spc->w[3]);
+      statp = stat;
+      for (ispec = 0; ispec < nspec; ispec++, xp += sx, statp++) {
+         if (*statp) continue;
+
+         s = *xp/spc->w[5] - spc->w[4];
+         if (fabs(s) <= 1.0) {
+            beta = asind(s);
+            *xp = tand(beta - spc->w[3]);
+         } else {
+            *statp = 1;
+         }
       }
    }
 
@@ -768,13 +795,11 @@ int stat[];
    xp = x;
    statp = stat;
    for (ispec = 0; ispec < nspec; ispec++, xp += sx) {
-      if (*(statp++)) {
-         continue;
-      }
+      if (*(statp++)) continue;
 
       *xp -= spc->w[1];
       *xp /= spc->w[2];
    }
 
-   return 0;
+   return status;
 }
