@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 3.1 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.2 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2003, Mark Calabretta
 *
 *   This library is free software; you can redistribute it and/or modify it
@@ -27,7 +27,7 @@
 *
 *=============================================================================
 *
-*   WCSLIB 3.1 - C routines that implement the spectral coordinate systems
+*   WCSLIB 3.2 - C routines that implement the spectral coordinate systems
 *   recognized by the FITS World Coordinate System (WCS) convention.  Refer to
 *
 *      "Representations of world coordinates in FITS",
@@ -57,13 +57,14 @@
 *   This service routine may be used to set the members of a spcprm struct to
 *   default values.
 *
-*   Returned:
+*   Given and returned:
 *      spc      struct spcprm*
 *                        Spectral transformation parameters (see below).
 *
 *   Function return value:
 *               int      Error status
 *                           0: Success.
+*                           1: Null spcprm pointer passed.
 *
 *
 *   Print routine for the spcprm struct; spcprt()
@@ -77,6 +78,7 @@
 *   Function return value:
 *               int      Error status
 *                           0: Success.
+*                           1: Null spcprm pointer passed.
 *
 *
 *   Initialization routine; spcset()
@@ -95,7 +97,8 @@
 *   Function return value:
 *               int      Error status
 *                           0: Success.
-*                           1: Invalid spectral parameters.
+*                           1: Null spcprm pointer passed.
+*                           2: Invalid spectral parameters.
 *
 *
 *   Transform to spectral coordinates; spcx2s()
@@ -116,14 +119,15 @@
 *      spec     double[] Spectral coordinate, in SI units.
 *      stat     int[]    Error status for each vector element:
 *                           0: Success.
-*                           1: Invalid intermediate world coordinate.
+*                           1: Invalid value of x.
 *
 *   Function return value:
 *               int      Error status
 *                           0: Success.
-*                           1: Invalid spectral parameters.
-*                           2: One or more invalid intermediate world
-*                              coordinates.
+*                           1: Null spcprm pointer passed.
+*                           2: Invalid spectral parameters.
+*                           3: One or more of the x coordinates were invalid,
+*                              as indicated by the stat vector.
 *
 *
 *   Transform spectral coordinates; spcs2x()
@@ -145,13 +149,15 @@
 *      x        double[] Intermediate world coordinates, in SI units.
 *      stat     int[]    Error status for each vector element:
 *                           0: Success.
-*                           1: Invalid spectral coordinate.
+*                           1: Invalid value of spec.
 *
 *   Function return value:
 *               int      Error status
 *                           0: Success.
-*                           1: Invalid spectral parameters.
-*                           2: One or more invalid spectral coordinates.
+*                           1: Null spcprm pointer passed.
+*                           2: Invalid spectral parameters.
+*                           4: One or more of the spec coordinates were
+*                              invalid, as indicated by the stat vector.
 *
 *
 *   Spectral transformation parameters
@@ -242,7 +248,7 @@
 *
 *   Error codes
 *   -----------
-*   Error messages to match the function return error code for all routines
+*   Error messages to match the error codes returned from each function are
 *   are encoded in the spc_errmsg character array.
 *
 *
@@ -265,7 +271,7 @@
 *
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
-*   $Id: spc.h,v 3.1 2003/04/28 03:50:41 mcalabre Exp $
+*   $Id: spc.h,v 3.2 2003/09/09 04:04:04 mcalabre Exp $
 *===========================================================================*/
 
 #ifndef WCSLIB_SPC
@@ -284,9 +290,12 @@ extern "C" {
 #endif
 
 
-extern const char *spcset_errmsg[];
-extern const char *spcx2s_errmsg[];
-extern const char *spcs2x_errmsg[];
+extern const char *spc_errmsg[];
+#define spcini_errmsg spc_errmsg
+#define spcprt_errmsg spc_errmsg
+#define spcset_errmsg spc_errmsg
+#define spcx2s_errmsg spc_errmsg
+#define spcs2x_errmsg spc_errmsg
 
 extern const int  spc_ncode;
 extern const char spc_codes[15][4];
@@ -332,7 +341,7 @@ struct spcprm {
    int (*spxs2q)(SPX_ARGS);	/* Pointers to the transformation functions */
    int (*spxq2x)(SPX_ARGS);	/* in the two-step algorithm chain in the   */
 				/* spectral-to-pixel direction.             */
-   int    padding;		/* (Dummy inserted for alignment purposes.) */
+   int padding;			/* (Dummy inserted for alignment purposes.) */
 };
 
 #define SPCLEN (sizeof(struct spcprm)/sizeof(int))
