@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 3.1 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.2 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2003, Mark Calabretta
 *
 *   This program is free software; you can redistribute it and/or modify it
@@ -31,7 +31,7 @@
 *   by drawing native and celestial coordinate graticules for Bonne's
 *   projection.
 *
-*   $Id: tcel.c,v 3.1 2003/04/28 04:27:07 mcalabre Exp $
+*   $Id: tcel.c,v 3.2 2003/09/09 04:40:16 mcalabre Exp $
 *---------------------------------------------------------------------------*/
 
 #include <cpgplot.h>
@@ -56,19 +56,9 @@ int main()
    printf("-----------------------------------------------------------\n");
 
    /* List error messages. */
-   printf("\nList of celset error codes:\n");
-   for (k = 1; k <= 3 ; k++) {
-      printf("   %d: %s.\n", k, celset_errmsg[k]);
-   }
-
-   printf("\nList of celx2s error codes:\n");
-   for (k = 1; k <= 4 ; k++) {
-      printf("   %d: %s.\n", k, celx2s_errmsg[k]);
-   }
-
-   printf("\nList of cels2x error codes:\n");
-   for (k = 1; k <= 4 ; k++) {
-      printf("   %d: %s.\n", k, cels2x_errmsg[k]);
+   printf("\nList of cel error codes:\n");
+   for (k = 1; k <= 6 ; k++) {
+      printf("   %d: %s.\n", k, cel_errmsg[k]);
    }
 
    printf("\n");
