@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   WCSLIB 3.1 - an implementation of the FITS WCS convention.
+*   WCSLIB 3.2 - an implementation of the FITS WCS convention.
 *   Copyright (C) 1995-2003, Mark Calabretta
 *
 *   This program is free software; you can redistribute it and/or modify it
@@ -30,7 +30,7 @@
 *   twcs1 tests wcss2p() and wcsp2s() for closure on the 1 degree celestial
 *   graticule for a number of selected projections.
 *
-*   $Id: twcs1.c,v 3.1 2003/04/28 04:27:07 mcalabre Exp $
+*   $Id: twcs1.c,v 3.2 2003/09/09 04:40:16 mcalabre Exp $
 *---------------------------------------------------------------------------*/
 
 #include <malloc.h>
@@ -94,34 +94,9 @@ int main()
           "----------------\n");
 
    /* List error messages. */
-   printf("\nList of wcsini error codes:\n");
-   for (j = 1; j <= 1 ; j++) {
-      printf("   %d: %s.\n", j, wcsini_errmsg[j]);
-   }
-
-   printf("\nList of wcscpy error codes:\n");
-   for (j = 1; j <= 1 ; j++) {
-      printf("   %d: %s.\n", j, wcscpy_errmsg[j]);
-   }
-
-   printf("\nList of wcsset error codes:\n");
-   for (j = 1; j <= 6 ; j++) {
-      printf("   %d: %s.\n", j, wcsset_errmsg[j]);
-   }
-
-   printf("\nList of wcsp2s error codes:\n");
-   for (j = 1; j <= 7 ; j++) {
-      printf("   %d: %s.\n", j, wcsp2s_errmsg[j]);
-   }
-
-   printf("\nList of wcss2p error codes:\n");
-   for (j = 1; j <= 7 ; j++) {
-      printf("   %d: %s.\n", j, wcss2p_errmsg[j]);
-   }
-
-   printf("\nList of wcsmix error codes:\n");
-   for (j = 1; j <= 8 ; j++) {
-      printf("   %d: %s.\n", j, wcsmix_errmsg[j]);
+   printf("\nList of wcs error codes:\n");
+   for (j = 1; j <= 11 ; j++) {
+      printf("   %d: %s.\n", j, wcs_errmsg[j]);
    }
 
 
@@ -269,6 +244,7 @@ void wcsex()
 
    /* The following routine simulates the actions of a FITS header parser. */
    wcs = (struct wcsprm *)malloc(sizeof(struct wcsprm));
+   wcs->flag = -1;
    parser(wcs);
 
    printf("\nTesting %s; reporting tolerance %5.1g deg.\n", wcs->cel.prj.code,
