@@ -1,6 +1,6 @@
 /*============================================================================
 *
-*   PGSBOX - a non-linear coordinate axis plotter for PGPLOT.
+*   PGSBOX 3.2 - a non-linear coordinate axis plotter for PGPLOT.
 *   Copyright (C) 1997-2003, Mark Calabretta
 *
 *   This program is free software; you can redistribute it and/or modify it
@@ -26,12 +26,12 @@
 *                      AUSTRALIA
 *
 *   Author: Mark Calabretta, Australia Telescope National Facility
-*   $Id: cpgtest.c,v 3.1 2003/04/28 05:02:51 mcalabre Exp $
+*   $Id: cpgtest.c,v 3.2 2003/09/09 07:52:48 mcalabre Exp $
 *=============================================================================
 *
 *   cpgtest
 *
-*   $Id: cpgtest.c,v 3.1 2003/04/28 05:02:51 mcalabre Exp $
+*   $Id: cpgtest.c,v 3.2 2003/09/09 07:52:48 mcalabre Exp $
 *---------------------------------------------------------------------------*/
 
 #include <math.h>
@@ -328,6 +328,7 @@ int main()
    *      time format.
    *------------------------------------------------------------------------*/
 
+   wcs.flag = -1;
    status = wcsini(1, 2, &wcs);
 
    /* Set projection type to SIN. */
@@ -993,10 +994,10 @@ int main()
    cpgpage();
 
   /*--------------------------------------------------------------------------
-   *     Ninth example: Calendar axes.  PGSBOX uses subroutine PGCRFN.
+   *     Ninth example: Calendar axes using subroutine PGLBOX.
    *     Features:
    *        - Separable (i.e. orthogonal), linear coordinate system.
-   *        - Use of function PGCRFN for separable axis types.
+   *        - Use of PGLBOX for simple linear axis types.
    *        - Automatic choice of what edges to label; results in labelling
    *          the bottom and left sides of the plot.
    *        - Automatic choice of coordinate increments.
@@ -1004,21 +1005,7 @@ int main()
    *        - Single-character annotation on a vertical axis is upright.
    *------------------------------------------------------------------------*/
 
-   /* Function types. */
-   strcpy(fcode[0], "Lin ");
-   strcpy(fcode[1], "Lin ");
-
-   /* Reference pixel coordinates. */
-   nldprm[0] = 0.5;
-   nldprm[1] = 0.5;
-
-   /* Coordinate increments. */
-   nldprm[2] =  0.5;
-   nldprm[3] = 10.0;
-
-   /* Reference pixel values. */
-   nldprm[4] = 51900.0;
-   nldprm[5] = 51900.0;
+   cpgswin(51900.0f, 52412.0f, 51900.0f, 57020.0f);
 
    /* Annotation. */
    strcpy(idents[0], "Date started");
@@ -1039,8 +1026,8 @@ int main()
    grid2[0] = 0.0;
 
    ic = -1;
-   cpgsbox(blc, trc, idents, opt, 0, 0, c0, gcode, 2.0, 0, grid1, 0, grid2, 0,
-      pgcrfn_, 8, 2, 4, fcode[0], nliprm, nldprm, 256, &ic, cache, &ierr);
+   cpglbox(idents, opt, 0, 0, c0, gcode, 2.0, 0, grid1, 0, grid2, 0, 256, &ic,
+      cache, &ierr);
 
    /* Draw the frame. */
    cpgbox("BC", 0.0f, 0, "BC", 0.0f, 0);
